@@ -1,22 +1,3 @@
-#' Available locales
-#'
-#' @export
-#' @return a data.frame of the available locales in this package.
-#' See [available_locales_df] for structure.
-#'
-#' Not all functions support all locales. Check the docs for each one
-#' to see what locales they support.
-#'
-#' You can find out more about each locale by running your locale
-#' though `stringi::stri_locale_info()`
-#' @examples
-#' charlatan_locales()
-charlatan_locales <- function() available_locales_df
-
-# generate with:
-# available_locales_df <- data.table::setDF(data.table::rbindlist(
-#      lapply(available_locales, stringi::stri_locale_info)))
-# save(available_locales_df, version=2, file="data/available_locales_df.rda")
 available_locales <- c(
   "ar_AA",
   "bg_BG",
@@ -56,6 +37,7 @@ available_locales <- c(
   "nl_BE",
   "nl_NL",
   "no_NO",
+  "nn_NO",
   "pl_PL",
   "pt_BR",
   "pt_PT",
@@ -73,7 +55,25 @@ available_locales <- c(
 
 #' Available locales
 #'
-#' A data.frame of locales available in \pkg{charlatan}
+#' @export
+#' @return a data.frame of the available locales in this package.
+#' See [available_locales_df] for structure.
+#'
+#' Not all functions support all locales. Check the docs for each one
+#' to see what locales they support.
+#'
+#' You can find out more about each locale by running your locale
+#' though `stringi::stri_locale_info()`
+#' @examples
+#' charlatan_locales()
+charlatan_locales <- function() available_locales_df
+
+
+#' Available locales
+#'
+#' A data.frame of locales available in \pkg{charlatan}.
+#' All localized providers are linked in the documentation.
+#'
 #'
 #' @format A data frame with 45 rows and 4 variables:
 #' \describe{
