@@ -10,9 +10,9 @@
 #' @importFrom whisker whisker.render
 #' @importFrom tibble as_tibble
 #' @aliases charlatan
-#' @docType package
 #' @keywords package
-#' @author Scott Chamberlain \email{myrmecocystus+r@@gmail.com}
+#' @author Roel M. Hogervorst \email{hogervorst.rm@gmail.com}
+#' @author Scott Chamberlain
 #' @author Kyle Voytovich
 #' @author Martin Pedersen
 #'
@@ -46,7 +46,7 @@
 #' # low level interfaces to "data providers"
 #' # these are exported by hidden from package man page
 #' # as most users will likely not interact with these
-#' x <- ColorProvider$new()
+#' x <- ColorProvider_en_US$new()
 #' x$color_name()
 #' x$hex_color()
-NULL
+"_PACKAGE"
