@@ -10,6 +10,7 @@
 #' z$position(bbox = c(-120, 30, -110, 60))
 CoordinateProvider <- R6::R6Class(
   "CoordinateProvider",
+  inherit = BareProvider,
   public = list(
     #' @description a latitude value
     lon = function() private$rnd() * 360,
@@ -28,6 +29,7 @@ CoordinateProvider <- R6::R6Class(
     }
   ),
   private = list(
+    provider_ = "CoordinateProvider",
     rnd = function() stats::runif(1) - 0.5,
     coord_in_bbbox = function(bbox) {
       stopifnot(0 <= abs(bbox[1]) && abs(bbox[1]) <= 180)
