@@ -1,5 +1,6 @@
 #' DOIProvider
 #'
+#' Generate random Digital Object Identifyers, used in scientific journals.
 #' @export
 #' @keywords internal
 #' @examples
@@ -7,7 +8,7 @@
 #' z$render()
 DOIProvider <- R6::R6Class(
   "DOIProvider",
-  inherit = BaseProvider,
+  inherit = BareProvider,
   public = list(
     #' @field funs (list) list of functions to use to apply to DOI creation
     funs = list(
@@ -37,5 +38,7 @@ DOIProvider <- R6::R6Class(
       x <- super$random_element(seq_along(self$funs))
       self$funs[[x]]()
     }
+  ), private = list(
+    provider_ = "DOIProvider"
   )
 )
