@@ -15,9 +15,9 @@
 ch_element_symbol <- function(n = 1) {
   assert(n, c("integer", "numeric"))
   if (n == 1) {
-    ElementProvider$new()$symbol()
+    ElementProvider_en_US$new()$symbol()
   } else {
-    x <- ElementProvider$new()
+    x <- ElementProvider_en_US$new()
     replicate(n, x$symbol())
   }
 }
@@ -27,9 +27,9 @@ ch_element_symbol <- function(n = 1) {
 ch_element_element <- function(n = 1) {
   assert(n, c("integer", "numeric"))
   if (n == 1) {
-    ElementProvider$new()$element()
+    ElementProvider_en_US$new()$element()
   } else {
-    x <- ElementProvider$new()
+    x <- ElementProvider_en_US$new()
     replicate(n, x$element())
   }
 }
