@@ -1,7 +1,7 @@
 # modified from the python library faker:
 # https://github.com/joke2k/faker/blob/master/faker/providers/job/__init__.py
 
-job_formats_en_us = c(
+job_formats_en_us <- c(
   "Academic librarian",
   "Accommodation manager",
   "Accountant, chartered",
@@ -642,3 +642,21 @@ job_formats_en_us = c(
   "Writer",
   "Youth worker"
 )
+
+#' Job provider for United States
+#'
+#' @inherit JobProvider description details return
+#' @family en
+#' @family US
+#' @export
+#' @examples
+#' x <- JobProvider_en_US$new()
+#' x$render()
+JobProvider_en_US <- R6::R6Class(
+  inherit = JobProvider,
+  "JobProvider_en_US",
+  private = list(
+    locale_ = "en_US",
+    formats = job_formats_en_us
+  )
+)
