@@ -978,3 +978,32 @@ lorem_word_list_en_us <- c(
   "your",
   "yourself"
 )
+
+#' Lorem provider English (USA)
+#'
+#' Methods for Lorem Ipsum generation.
+#' Lorem Ipsum is a placeholder text commonly used to demonstrate the visual
+#' form of a document or a typeface without relying on meaningful content.
+#' @family en
+#' @family US
+#' @export
+#' @examples
+#' x <- LoremProvider_en_US$new()
+#' x$word()
+#' x$words(3)
+#' x$words(6)
+#' x$sentence()
+#' x$paragraph()
+#' x$paragraphs(3)
+#' cat(x$paragraphs(6), sep = "\n")
+#' x$text(19)
+#' x <- LoremProvider_en_US$new(word_connector = " --- ")
+#' x$paragraph(4)
+LoremProvider_en_US <- R6::R6Class(
+  inherit = LoremProvider,
+  "LoremProvider_en_US",
+  private = list(
+    locale_ = "en_US",
+    word_list = lorem_word_list_en_us
+  )
+)
