@@ -10,10 +10,10 @@
 #' ch_missing(letters, 20)
 ch_missing <- function(x, n = 1) {
   assert(n, c("integer", "numeric"))
+  mdp <- MissingDataProvider$new()
   if (n == 1) {
-    MissingDataProvider$new()$make_missing(x)
+    mdp$make_missing(x)
   } else {
-    mdp <- MissingDataProvider$new()
     replicate(n, mdp$make_missing(x))
   }
 }
