@@ -1780,3 +1780,36 @@ person_bg_bg <- list(
   prefixes_female = person_prefixes_female_bg_bg,
   prefixes_male = person_prefixes_male_bg_bg
 )
+
+
+#' @title Person Provider for Bulgarian (Bulgaria)
+#' @inherit PersonProvider description details return
+#' @export
+#' @family bg
+#' @family BG
+#' @details Note for female and male components that we fall back on generic
+#' versions if the locale
+#' doesn't provide a male/female version.
+#' e.g., if no female first name we use first
+#' name
+#' @examples
+#' x <- PersonProvider_bg_BG$new()
+#' x$locale
+#' x$render()
+#' x$first_name()
+#' x$first_name_female()
+#' x$first_name_male()
+#' x$last_name()
+#' x$last_name_female()
+#' x$last_name_male()
+PersonProvider_bg_BG <- R6::R6Class(
+  "PersonProvider_bg_BG",
+  inherit = PersonProvider,
+  private = list(
+    # person name formats
+    formats = person_formats_bg_bg,
+    # person name data
+    persons = person_bg_bg,
+    locale_ = "bg_BG"
+  )
+)
