@@ -1560,3 +1560,37 @@ person_ne_np <- list(
   prefixes_male = person_prefixes_male_ne_np,
   prefixes = person_prefixes_ne_np
 )
+
+
+#' @title Person Provider for Nepali (Nepal)
+#' @inherit PersonProvider description details return
+#' @export
+#' @family ne
+#' @family NP
+#' @details Note for female and male components that we fall back on generic
+#' versions if the locale
+#' doesn't provide a male/female version.
+#' e.g., if no female first name we use first
+#' name
+#' @examples
+#' x <- PersonProvider_ne_NP$new()
+#' x$locale
+#' x$render()
+#' x$first_name()
+#' x$first_name_female()
+#' x$first_name_male()
+#' x$last_name()
+#' x$last_name_female()
+#' x$last_name_male()
+PersonProvider_ne_NP <- R6::R6Class(
+  "PersonProvider_ne_NP",
+  inherit = PersonProvider,
+  private = list(
+
+    # person name formats
+    formats = person_formats_ne_np,
+    # person name data
+    persons = person_ne_np,
+    locale_ = "ne_NP"
+  )
+)
