@@ -357,3 +357,36 @@ person_no_no <- list(
   last_names = person_last_names_no_no,
   prefixes = person_prefixes_no_no
 )
+
+#' @title Person Provider for Norwegian (Norway)
+#' @inherit PersonProvider description details return
+#' @export
+#' @family no
+#' @family NO
+#' @details Note for female and male components that we fall back on generic
+#' versions if the locale
+#' doesn't provide a male/female version.
+#' e.g., if no female first name we use first
+#' name
+#' @examples
+#' x <- PersonProvider_no_NO$new()
+#' x$locale
+#' x$render()
+#' x$first_name()
+#' x$first_name_female()
+#' x$first_name_male()
+#' x$last_name()
+#' x$last_name_female()
+#' x$last_name_male()
+PersonProvider_no_NO <- R6::R6Class(
+  "PersonProvider_no_NO",
+  inherit = PersonProvider,
+  private = list(
+
+    # person name formats
+    formats = person_formats_no_no,
+    # person name data
+    persons = person_no_no,
+    locale_ = "no_NO"
+  )
+)
