@@ -9,7 +9,7 @@
 #' @examples
 #' ch_phone_number()
 #' ch_phone_number(10)
-#' ch_phone_number(500)
+#' # or even ch_phone_number(500)
 #'
 #' # locales
 #' ch_phone_number(locale = "fr_FR")
@@ -18,10 +18,13 @@
 #' ch_phone_number(locale = "lv_LV")
 ch_phone_number <- function(n = 1, locale = NULL) {
   assert(n, c("integer", "numeric"))
+  if (is.null(locale)) {
+    locale <- "en_US"
+  }
+  pn <- cr_loc_spec_provider("PhoneNumberProvider", locale)
   if (n == 1) {
-    PhoneNumberProvider$new(locale = locale)$render()
+    pn$render()
   } else {
-    x <- PhoneNumberProvider$new(locale = locale)
-    replicate(n, x$render())
+    replicate(n, pn$render())
   }
 }
