@@ -11,10 +11,13 @@
 #' ch_ssn(10)
 ch_ssn <- function(n = 1, locale = NULL) {
   assert(n, c("integer", "numeric"))
+  if (is.null(locale)) {
+    locale <- "en_US"
+  }
+  x <- cr_loc_spec_provider("SSNProvider", locale)
   if (n == 1) {
-    SSNProvider$new(locale = locale)$render()
+    x$render()
   } else {
-    x <- SSNProvider$new(locale = locale)
     replicate(n, x$render())
   }
 }
