@@ -1,72 +1,26 @@
 #' @title UserAgentProvider
 #' @description user agent methods
+#' For instance mac_processor, user_agents, chrome and firefox user agents.
+#' @family ParentProviders
 #' @export
-#' @keywords internal
-#' @examples
-#' (x <- UserAgentProvider$new())
-#' x$locale
-#' x$mac_processor()
-#' x$linux_processor()
-#' x$user_agent()
-#' x$chrome()
-#' x$firefox()
-#' x$internet_explorer()
-#' x$opera()
-#' x$safari()
+#' @returns UserAgentProvider object.
 UserAgentProvider <- R6::R6Class(
   inherit = BaseProvider,
   "UserAgentProvider",
   public = list(
-    #' @field locale (character) the locale
-    locale = NULL,
-    #' @field user_agents (character) user agent browser specific strings
-    user_agents = c(
-      "chrome", "firefox", "internet_explorer", "opera", "safari"
-    ),
-    #' @field windows_platform_tokens (character) windows platform tokens
-    windows_platform_tokens = c(
-      "Windows 95", "Windows 98", "Windows 98; Win 9x 4.90", "Windows CE",
-      "Windows NT 4.0", "Windows NT 5.0", "Windows NT 5.01",
-      "Windows NT 5.1", "Windows NT 5.2", "Windows NT 6.0", "Windows NT 6.1",
-      "Windows NT 6.2"
-    ),
-    #' @field linux_processors (character) linux processor options
-    linux_processors = c("i686", "x86_64"),
-    #' @field mac_processors (character) mac processor options
-    mac_processors = c("Intel", "PPC", "U; Intel", "U; PPC"),
-
-    #' @description fetch the allowed locales for this provider
-    allowed_locales = function() private$locales,
-
-    #' @description Create a new `UserAgentProvider` object
-    #' @param locale (character) the locale to use. See
-    #' `$allowed_locales()` for locales supported (default: en_US)
-    #' @return A new `UserAgentProvider` object
-    initialize = function(locale = NULL) {
-      if (!is.null(locale)) {
-        # check global locales
-        super$check_locale(locale)
-        # check person provider locales
-        check_locale_(locale, private$locales)
-        self$locale <- locale
-      } else {
-        self$locale <- "en_US"
-      }
-    },
-
     #' @description a mac processor
     mac_processor = function() {
-      super$random_element(self$mac_processors)
+      super$random_element(private$mac_processors)
     },
 
     #' @description a linux processor
     linux_processor = function() {
-      super$random_element(self$linux_processors)
+      super$random_element(private$linux_processors)
     },
 
     #' @description a random user agent string
     user_agent = function() {
-      name <- super$random_element(self$user_agents)
+      name <- super$random_element(private$user_agents)
       self[[name]]()
     },
 
@@ -228,25 +182,41 @@ UserAgentProvider <- R6::R6Class(
 
     #' @description a windows platform token
     windows_platform_token = function() {
-      super$random_element(self$windows_platform_tokens)
+      super$random_element(private$windows_platform_tokens)
     },
 
     #' @description a linux platform token
     linux_platform_token = function() {
-      paste0("X11; Linux ", super$random_element(self$linux_processors))
+      paste0("X11; Linux ", super$random_element(private$linux_processors))
     },
 
     #' @description a mac platform token
     mac_platform_token = function() {
       sprintf(
         "Macintosh; %s Mac OS X 10_%s_%s",
-        super$random_element(self$mac_processors),
+        super$random_element(private$mac_processors),
         super$random_int(5, 12),
         super$random_int(0, 9)
       )
     }
   ),
   private = list(
-    locales = c("en_US")
+    locales = c("en_US"),
+    # user agent browser specific strings
+    user_agents = c(
+      "chrome", "firefox", "internet_explorer", "opera", "safari"
+    ),
+    # windows platform tokens
+    windows_platform_tokens = c(
+      "Windows 95", "Windows 98", "Windows 98; Win 9x 4.90", "Windows CE",
+      "Windows NT 4.0", "Windows NT 5.0", "Windows NT 5.01",
+      "Windows NT 5.1", "Windows NT 5.2", "Windows NT 6.0", "Windows NT 6.1",
+      "Windows NT 6.2"
+    ),
+    # linux processor options
+    linux_processors = c("i686", "x86_64"),
+    # mac processor options
+    mac_processors = c("Intel", "PPC", "U; Intel", "U; PPC"),
+    provider_ = "UserAgentProvider"
   )
 )
