@@ -1,55 +1,56 @@
-context("LoremProvider works")
-
 test_that("LoremProvider works", {
-  aa <- LoremProvider$new()
+  for (loc in LoremProvider_en_US$new()$allowed_locales()) {
+    aa <- cr_loc_spec_provider("LoremProvider", loc)
 
-  expect_is(aa, "LoremProvider")
-  expect_is(aa, "R6")
+    expect_s3_class(aa, "LoremProvider")
+    expect_s3_class(aa, "R6")
 
-  expect_is(aa$word, "function")
-  expect_is(aa$word(), "character")
-  expect_equal(length(aa$word()), 1)
+    expect_type(aa$word, "closure")
+    expect_type(aa$word(), "character")
+    expect_equal(length(aa$word()), 1)
+    expect_false(aa$word() == "")
 
-  expect_is(aa$words, "function")
-  expect_is(aa$words(), "character")
-  expect_equal(length(aa$words()), 3)
+    expect_type(aa$words, "closure")
+    expect_type(aa$words(), "character")
+    expect_equal(length(aa$words()), 3)
 
-  expect_is(aa$sentence, "function")
-  expect_is(aa$sentence(), "character")
-  expect_equal(length(aa$sentence()), 1)
+    expect_type(aa$sentence, "closure")
+    expect_type(aa$sentence(), "character")
+    expect_equal(length(aa$sentence()), 1)
 
-  expect_is(aa$sentences, "function")
-  expect_is(aa$sentences(), "character")
-  expect_equal(length(aa$sentences()), 3)
+    expect_type(aa$sentences, "closure")
+    expect_type(aa$sentences(), "character")
+    expect_equal(length(aa$sentences()), 3)
 
-  expect_is(aa$paragraph, "function")
-  expect_is(aa$paragraph(), "character")
-  expect_equal(length(aa$paragraph()), 1)
+    expect_type(aa$paragraph, "closure")
+    expect_type(aa$paragraph(), "character")
+    expect_equal(length(aa$paragraph()), 1)
 
-  expect_is(aa$paragraphs, "function")
-  expect_is(aa$paragraphs(), "character")
-  expect_equal(length(aa$paragraphs()), 3)
+    expect_type(aa$paragraphs, "closure")
+    expect_type(aa$paragraphs(), "character")
+    expect_equal(length(aa$paragraphs()), 3)
 
-  expect_is(aa$text, "function")
-  expect_is(aa$text(), "character")
-  expect_equal(length(aa$text()), 1)
+    expect_type(aa$text, "closure")
+    expect_type(aa$text(), "character")
+    expect_equal(length(aa$text()), 1)
+  }
 })
 
 test_that("LoremProvider fails well", {
+  # expect_error(
+  #   LoremProvider$new(locale = "foobar"),
+  #   "foobar not in set of available locales"
+  # )
   expect_error(
-    LoremProvider$new(locale = "foobar"),
-    "foobar not in set of available locales"
-  )
-  expect_error(
-    LoremProvider$new(sentence_punctuation = 5),
+    LoremProvider_en_US$new(sentence_punctuation = 5),
     "sentence_punctuation must be of class character"
   )
   expect_error(
-    LoremProvider$new(word_connector = 5),
+    LoremProvider_en_US$new(word_connector = 5),
     "word_connector must be of class character"
   )
 
-  aa <- LoremProvider$new()
+  aa <- LoremProvider_en_US$new()
 
   expect_error(
     aa$word(ext_words = 5),
