@@ -1,5 +1,3 @@
-context("MissingDataProvider")
-
 skip_on_cran()
 
 test_that("MissingDataProvider works", {
@@ -7,12 +5,12 @@ test_that("MissingDataProvider works", {
   letters2 <- aa$make_missing(letters)
   letters3 <- aa$make_missing(letters)
 
-  expect_is(aa, "R6")
-  expect_is(aa, "MissingDataProvider")
+  expect_s3_class(aa, "R6")
+  expect_s3_class(aa, "MissingDataProvider")
 
-  expect_is(aa$make_missing, "function")
+  expect_type(aa$make_missing, "closure")
 
-  expect_is(letters2, "character")
+  expect_type(letters2, "character")
 
   # original and with missing data are not the same
   expect_false(identical(letters, letters2))
@@ -30,14 +28,13 @@ test_that("MissingDataProvider fails well", {
 })
 
 
-context("ch_missing")
 
 test_that("ch_missing works", {
   letters2 <- ch_missing(letters)
   letters3 <- ch_missing(letters)
 
-  expect_is(letters2, "character")
-  expect_is(letters3, "character")
+  expect_type(letters2, "character")
+  expect_type(letters3, "character")
 
   # original and with missing data are not the same
   expect_false(identical(letters, letters2))
