@@ -1,9 +1,7 @@
-context("charlatan_settings")
-
 test_that("charlatan_settings - default", {
   aa <- charlatan_settings()
 
-  expect_is(aa, "list")
+  expect_type(aa, "list")
   expect_named(aa, "global_messy")
   expect_null(aa$global_messy)
 })
@@ -11,7 +9,7 @@ test_that("charlatan_settings - default", {
 test_that("charlatan_settings - set messy to TRUE", {
   aa <- charlatan_settings(messy = TRUE)
 
-  expect_is(aa, "list")
+  expect_type(aa, "list")
   expect_named(aa, "global_messy")
   expect_true(aa$global_messy)
 })
@@ -20,11 +18,11 @@ test_that("charlatan_settings - global settings override local settings", {
   # reset settings
   charlatan_settings()
 
-  aa <- PersonProvider$new()
+  aa <- PersonProvider_en_US$new()
   expect_false(aa$messy)
 
   charlatan_settings(messy = TRUE)
-
-  bb <- PersonProvider$new()
+  expect_warning(PersonProvider_en_US$new(messy = FALSE))
+  bb <- suppressWarnings(PersonProvider_en_US$new(messy = FALSE))
   expect_true(bb$messy)
 })
